﻿using System;
using System.Web.Script.Serialization;
using System.Xml;
using System.Collections.Generic;

using MindFusion.Diagramming;
using MindFusion.Diagramming.WebForms;


public class CustomLink : DiagramLink
{
	public CustomLink(Diagram diagram) : base(diagram)
	{
		linkType = 1;
	}

	protected override void SaveToXml(XmlElement xmlElement, XmlPersistContext context)
	{
		base.SaveToXml(xmlElement, context);
		context.WriteInt(linkType, "LinkType", xmlElement);
	}

	protected override void LoadFromXml(XmlElement xmlElement, XmlPersistContext context)
	{
		base.LoadFromXml(xmlElement, context);
		linkType = context.ReadInt("LinkType", xmlElement);
	}

	protected override void SaveTo(System.IO.BinaryWriter writer, PersistContext context)
	{
		base.SaveTo(writer, context);
		writer.Write(linkType);
	}

	protected override void LoadFrom(System.IO.BinaryReader reader, PersistContext context)
	{
		base.LoadFrom(reader, context);
		linkType = reader.ReadInt16();
	}


	public int LinkType
	{
		get { return linkType; }
		set
		{
			linkType = value;
		}
	}

	private int linkType;
}


public class CustomLinkConverter : DiagramLinkConverter
{
	public CustomLinkConverter(DiagramView view)
		: base(view)
	{
	}

	public override IEnumerable<Type> SupportedTypes
	{
		get { return new List<Type>(new Type[] { typeof(CustomLink) }); }
	}

	public override object Deserialize(
		IDictionary<string, object> dictionary, Type type, JavaScriptSerializer serializer)
	{
		CustomLink link = (CustomLink)base.Deserialize(dictionary, type, serializer);
		link.LinkType = int.Parse(dictionary["linkType"].ToString());
		return link;
	}

	public override IDictionary<string, object> Serialize(
		object obj, JavaScriptSerializer serializer)
	{
		CustomLink link = obj as CustomLink;
		if (link != null)
		{
			IDictionary<string, object> json = base.Serialize(obj, serializer);
			if (json != null)
			{
				json.Add("linkType", link.LinkType);
			}
			return json;
		}

		return null;
	}
}